pub struct AdminAction {
pub name: String,
pub label: String,
pub capability: String,
pub input_schema: Option<AdminActionInputSchema>,
pub confirmation: Option<AdminActionConfirmation>,
pub danger_level: AdminActionDangerLevel,
pub operation: Option<ServiceOperationMetadata>,
}Fields
name: Stringlabel: Stringcapability: Stringinput_schema: Option<AdminActionInputSchema>confirmation: Option<AdminActionConfirmation>danger_level: AdminActionDangerLeveloperation: Option<ServiceOperationMetadata>Trait Implementations
Sourceimpl Clone for AdminAction
impl Clone for AdminAction
Sourcefn clone(&self) -> AdminAction
fn clone(&self) -> AdminAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminAction
impl Debug for AdminAction
Sourceimpl<'de> Deserialize<'de> for AdminAction
impl<'de> Deserialize<'de> for AdminAction
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminAction, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminAction, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminAction
Sourceimpl JsonSchema for AdminAction
impl JsonSchema for AdminAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminAction
impl PartialEq for AdminAction
Sourceimpl Serialize for AdminAction
impl Serialize for AdminAction
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AdminAction