pub struct AdminActionInputSchema {
pub fields: Vec<AdminActionInputField>,
}Fields
fields: Vec<AdminActionInputField>Trait Implementations
Sourceimpl Clone for AdminActionInputSchema
impl Clone for AdminActionInputSchema
Sourcefn clone(&self) -> AdminActionInputSchema
fn clone(&self) -> AdminActionInputSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminActionInputSchema
impl Debug for AdminActionInputSchema
Sourceimpl<'de> Deserialize<'de> for AdminActionInputSchema
impl<'de> Deserialize<'de> for AdminActionInputSchema
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminActionInputSchema, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminActionInputSchema, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminActionInputSchema
Sourceimpl JsonSchema for AdminActionInputSchema
impl JsonSchema for AdminActionInputSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminActionInputSchema
impl PartialEq for AdminActionInputSchema
Sourceimpl Serialize for AdminActionInputSchema
impl Serialize for AdminActionInputSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AdminActionInputSchema