pub struct AdminEmbeddedSurface {
pub runtime: AdminEmbeddedRuntime,
pub entry: AdminEmbeddedEntry,
pub sandbox: AdminSandboxPolicy,
pub permissions: Vec<AdminPermission>,
pub fallback_schema: Option<AdminSchema>,
}Fields
runtime: AdminEmbeddedRuntimeentry: AdminEmbeddedEntrysandbox: AdminSandboxPolicypermissions: Vec<AdminPermission>fallback_schema: Option<AdminSchema>Trait Implementations
Sourceimpl Clone for AdminEmbeddedSurface
impl Clone for AdminEmbeddedSurface
Sourcefn clone(&self) -> AdminEmbeddedSurface
fn clone(&self) -> AdminEmbeddedSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminEmbeddedSurface
impl Debug for AdminEmbeddedSurface
Sourceimpl<'de> Deserialize<'de> for AdminEmbeddedSurface
impl<'de> Deserialize<'de> for AdminEmbeddedSurface
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminEmbeddedSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AdminEmbeddedSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdminEmbeddedSurface
Sourceimpl JsonSchema for AdminEmbeddedSurface
impl JsonSchema for AdminEmbeddedSurface
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdminEmbeddedSurface
impl PartialEq for AdminEmbeddedSurface
Sourceimpl Serialize for AdminEmbeddedSurface
impl Serialize for AdminEmbeddedSurface
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AdminEmbeddedSurface