pub struct ConsoleContribution {
pub target: String,
pub target_version: u32,
pub label: String,
pub action: ConsoleContributionAction,
pub icon: Option<String>,
pub required_capabilities: Vec<String>,
}Fields
target: Stringtarget_version: u32label: Stringaction: ConsoleContributionActionicon: Option<String>required_capabilities: Vec<String>Trait Implementations
Sourceimpl Clone for ConsoleContribution
impl Clone for ConsoleContribution
Sourcefn clone(&self) -> ConsoleContribution
fn clone(&self) -> ConsoleContribution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleContribution
impl Debug for ConsoleContribution
Sourceimpl<'de> Deserialize<'de> for ConsoleContribution
impl<'de> Deserialize<'de> for ConsoleContribution
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleContribution, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleContribution, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleContribution
Sourceimpl JsonSchema for ConsoleContribution
impl JsonSchema for ConsoleContribution
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleContribution
impl PartialEq for ConsoleContribution
Sourceimpl Serialize for ConsoleContribution
impl Serialize for ConsoleContribution
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ConsoleContribution