pub struct ConsoleModuleManifest {
pub protocol: String,
pub module_id: String,
pub host_api: String,
pub console_ui: String,
pub surfaces: Vec<ConsoleModuleSurface>,
}Expand description
The immutable presentation manifest embedded in a console_ui_esm
artifact. Its field names intentionally match the public Console SDK.
Fields
protocol: Stringmodule_id: Stringhost_api: Stringconsole_ui: Stringsurfaces: Vec<ConsoleModuleSurface>Trait Implementations
Sourceimpl Clone for ConsoleModuleManifest
impl Clone for ConsoleModuleManifest
Sourcefn clone(&self) -> ConsoleModuleManifest
fn clone(&self) -> ConsoleModuleManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleModuleManifest
impl Debug for ConsoleModuleManifest
Sourceimpl<'de> Deserialize<'de> for ConsoleModuleManifest
impl<'de> Deserialize<'de> for ConsoleModuleManifest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleModuleManifest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleModuleManifest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleModuleManifest
Sourceimpl JsonSchema for ConsoleModuleManifest
impl JsonSchema for ConsoleModuleManifest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleModuleManifest
impl PartialEq for ConsoleModuleManifest
Sourceimpl Serialize for ConsoleModuleManifest
impl Serialize for ConsoleModuleManifest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ConsoleModuleManifest