pub struct ConsoleSlotContext {
pub name: String,
pub fields: Vec<ConsoleSlotContextField>,
}Fields
name: Stringfields: Vec<ConsoleSlotContextField>Trait Implementations
Sourceimpl Clone for ConsoleSlotContext
impl Clone for ConsoleSlotContext
Sourcefn clone(&self) -> ConsoleSlotContext
fn clone(&self) -> ConsoleSlotContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleSlotContext
impl Debug for ConsoleSlotContext
Sourceimpl<'de> Deserialize<'de> for ConsoleSlotContext
impl<'de> Deserialize<'de> for ConsoleSlotContext
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleSlotContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleSlotContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleSlotContext
Sourceimpl JsonSchema for ConsoleSlotContext
impl JsonSchema for ConsoleSlotContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleSlotContext
impl PartialEq for ConsoleSlotContext
Sourceimpl Serialize for ConsoleSlotContext
impl Serialize for ConsoleSlotContext
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ConsoleSlotContext