pub struct ConsoleSurface {
pub name: String,
pub label: String,
pub route: String,
pub presentation: ConsoleSurfacePresentation,
pub icon: Option<String>,
pub required_capabilities: Vec<String>,
pub navigation: Option<ConsoleNavigation>,
}Fields
name: Stringlabel: Stringroute: Stringpresentation: ConsoleSurfacePresentationicon: Option<String>required_capabilities: Vec<String>Trait Implementations
Sourceimpl Clone for ConsoleSurface
impl Clone for ConsoleSurface
Sourcefn clone(&self) -> ConsoleSurface
fn clone(&self) -> ConsoleSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsoleSurface
impl Debug for ConsoleSurface
Sourceimpl<'de> Deserialize<'de> for ConsoleSurface
impl<'de> Deserialize<'de> for ConsoleSurface
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConsoleSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConsoleSurface
Sourceimpl JsonSchema for ConsoleSurface
impl JsonSchema for ConsoleSurface
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConsoleSurface
impl PartialEq for ConsoleSurface
Sourceimpl Serialize for ConsoleSurface
impl Serialize for ConsoleSurface
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ConsoleSurface