pub struct EventSurface {
pub handlers: Vec<EventHandlerDeclaration>,
}Fields
handlers: Vec<EventHandlerDeclaration>Trait Implementations
Sourceimpl Clone for EventSurface
impl Clone for EventSurface
Sourcefn clone(&self) -> EventSurface
fn clone(&self) -> EventSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventSurface
impl Debug for EventSurface
Sourceimpl<'de> Deserialize<'de> for EventSurface
impl<'de> Deserialize<'de> for EventSurface
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<EventSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<EventSurface, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventSurface
Sourceimpl JsonSchema for EventSurface
impl JsonSchema for EventSurface
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventSurface
impl PartialEq for EventSurface
Sourceimpl Serialize for EventSurface
impl Serialize for EventSurface
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for EventSurface