pub struct LifecycleStartupCheckDeclaration {
pub name: String,
pub required: bool,
pub check: LifecycleStartupCheckKind,
}Fields
name: Stringrequired: boolcheck: LifecycleStartupCheckKindTrait Implementations
Sourceimpl Clone for LifecycleStartupCheckDeclaration
impl Clone for LifecycleStartupCheckDeclaration
Sourcefn clone(&self) -> LifecycleStartupCheckDeclaration
fn clone(&self) -> LifecycleStartupCheckDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for LifecycleStartupCheckDeclaration
impl<'de> Deserialize<'de> for LifecycleStartupCheckDeclaration
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LifecycleStartupCheckDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LifecycleStartupCheckDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LifecycleStartupCheckDeclaration
Sourceimpl JsonSchema for LifecycleStartupCheckDeclaration
impl JsonSchema for LifecycleStartupCheckDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for LifecycleStartupCheckDeclaration
impl Serialize for LifecycleStartupCheckDeclaration
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LifecycleStartupCheckDeclaration