pub struct ModuleManifestLint {
pub severity: ModuleManifestLintSeverity,
pub subject: String,
pub message: String,
pub suggestion: String,
}Fields
severity: ModuleManifestLintSeveritysubject: Stringmessage: Stringsuggestion: StringTrait Implementations
Sourceimpl Clone for ModuleManifestLint
impl Clone for ModuleManifestLint
Sourcefn clone(&self) -> ModuleManifestLint
fn clone(&self) -> ModuleManifestLint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleManifestLint
impl Debug for ModuleManifestLint
Sourceimpl<'de> Deserialize<'de> for ModuleManifestLint
impl<'de> Deserialize<'de> for ModuleManifestLint
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ModuleManifestLint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ModuleManifestLint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleManifestLint
Sourceimpl JsonSchema for ModuleManifestLint
impl JsonSchema for ModuleManifestLint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleManifestLint
impl PartialEq for ModuleManifestLint
Sourceimpl Serialize for ModuleManifestLint
impl Serialize for ModuleManifestLint
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ModuleManifestLint