pub struct ModuleRouteLint {
pub severity: ModuleRouteLintSeverity,
pub subject: String,
pub message: String,
pub suggestion: String,
}Fields
severity: ModuleRouteLintSeveritysubject: Stringmessage: Stringsuggestion: StringTrait Implementations
Sourceimpl Clone for ModuleRouteLint
impl Clone for ModuleRouteLint
Sourcefn clone(&self) -> ModuleRouteLint
fn clone(&self) -> ModuleRouteLint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleRouteLint
impl Debug for ModuleRouteLint
Sourceimpl<'de> Deserialize<'de> for ModuleRouteLint
impl<'de> Deserialize<'de> for ModuleRouteLint
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ModuleRouteLint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ModuleRouteLint, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleRouteLint
Sourceimpl JsonSchema for ModuleRouteLint
impl JsonSchema for ModuleRouteLint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleRouteLint
impl PartialEq for ModuleRouteLint
Sourceimpl Serialize for ModuleRouteLint
impl Serialize for ModuleRouteLint
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ModuleRouteLint