pub struct RuntimeFunctionDeclaration {
pub name: String,
pub version: u16,
pub queue: String,
pub input_schema: Option<String>,
pub retry_policy: Option<RuntimeRetryPolicyDeclaration>,
pub operation: Option<ServiceOperationMetadata>,
}Fields
name: StringStable function name used by runtime.function_runs.
version: u16Version for the declared function contract.
queue: StringQueue name the host should use when registering the function.
input_schema: Option<String>Optional schema identifier for the function input payload.
retry_policy: Option<RuntimeRetryPolicyDeclaration>Optional retry policy requested by the module. The host still owns enforcement and may clamp values when behavior registration is added.
operation: Option<ServiceOperationMetadata>Trait Implementations
Sourceimpl Clone for RuntimeFunctionDeclaration
impl Clone for RuntimeFunctionDeclaration
Sourcefn clone(&self) -> RuntimeFunctionDeclaration
fn clone(&self) -> RuntimeFunctionDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeFunctionDeclaration
impl Debug for RuntimeFunctionDeclaration
Sourceimpl<'de> Deserialize<'de> for RuntimeFunctionDeclaration
impl<'de> Deserialize<'de> for RuntimeFunctionDeclaration
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RuntimeFunctionDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RuntimeFunctionDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeFunctionDeclaration
Sourceimpl JsonSchema for RuntimeFunctionDeclaration
impl JsonSchema for RuntimeFunctionDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RuntimeFunctionDeclaration
impl Serialize for RuntimeFunctionDeclaration
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RuntimeFunctionDeclaration